@@ -4,6 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.hpo_metric import HPOMetric
 from myst.openapi.models.hpo_trial import HPOTrial
 
 
@@ -13,6 +14,6 @@ class HPOResultGet(base_model.BaseModel):
     object_: Literal["HPOResult"] = Field(..., alias="object")
     uuid: str
     create_time: str
-    metric: Literal["mse"]
+    metric: HPOMetric
     best_trial: HPOTrial
     trials: List[HPOTrial]
