@@ -4,9 +4,8 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.absolute_timing_get import AbsoluteTimingGet
-from ..models.relative_timing_get import RelativeTimingGet
+from myst.openapi.models.absolute_timing_get import AbsoluteTimingGet
+from myst.openapi.models.relative_timing_get import RelativeTimingGet
 
 
 class LayerGet(base_model.BaseModel):
