@@ -1,10 +1,10 @@
-from typing import Dict, List, Optional
+from typing import Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-from myst.models.time_dataset import TimeDataset
+from myst.openapi.models.model_fit_result_get_inputs import ModelFitResultGetInputs
 
 
 class ModelFitResultGet(base_model.BaseModel):
@@ -19,5 +19,5 @@ class ModelFitResultGet(base_model.BaseModel):
     end_time: str
     as_of_time: str
     fit_state_url: str
-    inputs: Dict[str, Optional[List[TimeDataset]]]
+    inputs: ModelFitResultGetInputs
     update_time: Optional[str] = None
