@@ -1,10 +1,11 @@
-from typing import Dict, List, Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
 from myst.models.time_dataset import TimeDataset
+from myst.openapi.models.model_run_result_get_inputs import ModelRunResultGetInputs
 
 
 class ModelRunResultGet(base_model.BaseModel):
@@ -18,6 +19,6 @@ class ModelRunResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     as_of_time: str
-    inputs: Dict[str, Optional[List[TimeDataset]]]
+    inputs: ModelRunResultGetInputs
     outputs: List[TimeDataset]
     update_time: Optional[str] = None
