@@ -1,9 +1,10 @@
-from typing import Dict, List, Optional, Union
+from typing import List, Optional, Union
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.time_dataset_metadata import TimeDatasetMetadata
 from myst.openapi.models.time_dataset_row import TimeDatasetRow
 
 
@@ -16,4 +17,4 @@ class TimeDataset(base_model.BaseModel):
     data: List[TimeDatasetRow]
     coordinate_labels: Optional[List[List[Union[int, str]]]] = None
     axis_labels: Optional[List[Union[int, str]]] = None
-    metadata: Optional[Dict[str, Optional[Union[str, int, float, bool]]]] = None
+    metadata: Optional[TimeDatasetMetadata] = None
