@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
-from typing import Optional
+from typing import Optional, Union
 
+from myst.models.types import UUIDOrStr
 from myst.resources.project import Project
 from myst.resources.time_series import TimeSeries
 
@@ -9,7 +10,9 @@ class TimeSeriesRecipe(ABC):
     """A recipe from which a time series can be created."""
 
     @abstractmethod
-    def create(self, project: Project, title: Optional[str] = None, description: Optional[str] = None) -> TimeSeries:
+    def create(
+        self, project: Union["Project", UUIDOrStr], title: Optional[str] = None, description: Optional[str] = None
+    ) -> TimeSeries:
         """Creates and returns a new time series from this recipe in the given project.
 
         Args:
