@@ -296,8 +296,8 @@ class TimeSeries(Node):
     def create_run_policy(
         self,
         schedule_timing: Union[Time, TimeDelta, ScheduleTiming],
-        start_timing: Optional[TimeRangeBoundary] = None,
-        end_timing: Optional[TimeRangeBoundary] = None,
+        start_timing: TimeRangeBoundary,
+        end_timing: TimeRangeBoundary,
         active: bool = True,
     ) -> TimeSeriesRunPolicy:
         return TimeSeriesRunPolicy.create(
